# cnncam
<!-- badges: start -->

[![PyPI version](https://badge.fury.io/py/cnncam.svg)](https://badge.fury.io/py/cnncam)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/pylint-dev/pylint) [![License:
MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/license/mit/) 
[![Lifecycle:
experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html) [![Github All Releases](https://img.shields.io/github/downloads/rawanmahdi/cnncam/total.svg)]()
<!-- [![DOI](https://joss.theoj.org/papers/10.21105/joss.02027/status.svg)](https://doi.org/10.21105/joss.02027)
 -->
<!-- badges: end -->


## Introduction

An open python library for researchers and developers to generate GradCAM explanations for the tensorflow CNN models. 

Other popular python ML frameworks will soon be supported by the cnn-cam library

### Install

The below instructions assume you already have `pip` installed and exposed to the python environment where you want to run `cnncam`. 
Official instructions for installing `pip` can be found [here](https://pip.pypa.io/en/stable/installation/)

Run the below pip command in a shell of your choice. 
```
pip install cnncam
```

### Demo

```python
from cnncam import GradCAM
from keras.applica

```


See `/examples` for executable examples, including an application of our implementation of GradCAM on VGG-16 with the ower of this repo's very cute cat, meso.